DISMaL: Demographic Inference under the Structured Coalescent using Maximum Likelihood
======================================================================================

``DISMaL`` is a Python package for inferring historical demographies
(specifically, population sizes, gene flow, and split times) from
sequence data. It is an implementation of the *Generalised
isolation-with-migration* (GIM) model of Costa & Wilkinson-Herbots
(2021). Please cite their paper if you use ``DISMaL`` in published work:

*Rui J. Costa, Hilde M. Wilkinson-Herbots (2021). Inference of gene flow
in the process of speciation: Efficient maximum-likelihood
implementation of a generalised isolation-with-migration model.
Theoretical Population Biology 140:1-15.
https://doi.org/10.1016/j.tpb.2021.03.001.*

Documentation is hosted on ReadTheDocs: https://dismal.readthedocs.io/en/latest/


Installation
------------

DISMaL is currently only available as a pre-release from this GitHub
repo. Install using:

::

   pip install git+https://github.com/simonharnqvist/DISMaL.git#egg=dismal
